<?php

/*
    Plugin Name: Analytify PRO
    Plugin URI: http://wp-analytify.com/
    Description: Analytify makes Google Analytics simple for everything in WordPress (posts,pages etc). It presents the statistics in a beautiful way under the WordPress Posts/Pages at front end, backend and in its own Dashboard. This provides Stats from Country, Referrers, Social media, General stats, New visitors, Returning visitors, Exit pages, Browser wise and Top keywords. This plugin provides the RealTime statistics in a new UI that is easy to understand and looks good.
    Version: 1.2.2
    Author: Adnan
    Author URI: http://adnan.pk/
    License: GPLv2+
    Text Domain: wp-analytify
    Domain Path: /lang
*/


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

    ini_set( 'include_path', dirname(__FILE__) . '/lib/' );

    if( !class_exists( 'Analytify_General' ) ) {

        include_once WP_PLUGIN_DIR .'/wp-analytify-pro/analytify-general.php';
    }

if( !class_exists( 'WP_Analytify' ) ) {
    /**
     * Main WP_Analytify class
     *
     * @since       1.0.0
     */


    class WP_Analytify extends Analytify_General{

        /**
         * @var         WP_Analytify $instance The one true WP_Analytify
         * @since       1.2.2
         */
        private static $instance;

        public $token  = false;
        public $client = null;

        /**
         * Get active instance
         *
         * @access      public
         * @since       1.2.2
         * @return      object self::$instance The one true WP_Analytify
         */
        public static function instance() {
            if( !self::$instance ) {
                self::$instance = new WP_Analytify();
                self::$instance->setup_constants();
                self::$instance->includes();
                self::$instance->load_textdomain();
                self::$instance->hooks();
            }
            return self::$instance;
        }

        /**
         * Setup plugin constants
         *
         * @access      private
         * @since       1.2.2
         * @return      void
         */
        private function setup_constants() {

            // Setting Global Values

        }

        /**
         * Include necessary files
         *
         * @access      private
         * @since       1.2.2
         * @return      void
         */
        private function includes() {

            if ( !class_exists( 'EDD_SL_Plugin_Updater' ) ) {
                // load plugin updater
                include_once( dirname( __FILE__ ) . '/lib/EDD_SL_Plugin_Updater.php' );
            }
            require_once WP_PLUGIN_DIR . '/wp-analytify-pro/welcome.php';

        }

        /**
         * Run action and filter hooks
         *
         * @access      private
         * @since       1.2.2
         * @return      void
         *
         */
        private function hooks() {

            add_action( 'plugin_action_links', array( 
                        $this,
                        'pa_plugin_links'
                    ),10,2);

            add_action( 'plugin_row_meta', array( 
                        $this,
                        'analytify_plugin_row_meta'
                    ),10,2);

            add_action( 'admin_enqueue_scripts', array( 
                        $this,
                        'pa_scripts'
                    ));
            add_action( 'admin_enqueue_scripts', array( 
                        $this,
                        'pa_styles'
                    ));
        
            

            add_action( 'wp_enqueue_scripts', array( 
                        $this,
                        'pa_front_scripts'
                    ));
            add_action( 'wp_enqueue_scripts', array( 
                        $this,
                        'pa_front_styles'
                    ));
        
            add_action( 'admin_menu', array(
                        $this,
                        'wpa_add_menu'
                    ));

            add_action( 'admin_init', array(
                        $this,
                        'analytify_plugin_updater'
                    ),0);

            // initiating ShortCodes
            add_action( 'admin_head', array(
                        $this,
                        'analytify_shortcode_button'
                    ));
            add_action( 'edd_license_key', array(
                        &$this,
                        'add_edd_license_key'
                      ),10);

            add_filter( 'mce_css', array(
                        $this, 
                        'analytify_mce_css' 
                      ));

            add_shortcode( 'analytify-stats', array( 
                            $this, 
                            'analytify_stats_shortcode'));

            add_action( 'wp_ajax_analytify_advanced_shortcode', array( 
                        $this,
                        'analytify_shortcode_view' ) );


            add_action( 'admin_init', array(
                        $this, 
                        'wp_analytify_register_option' 
                      ) );
            
            add_action( 'admin_init', array(
                        $this, 
                        'analytify_activate_license' 
                      ) );
            
            add_action( 'admin_init', array(
                        $this, 
                        'analytify_deactivate_license' 
                      ) );

            // Insert Google Analytics Code
            if( get_option( 'analytify_code') == 1  ) {

                add_action( 'wp_head', array(
                        $this,
                        'analytify_add_analytics_code'
                    ));
            }

            add_action( 'wp_ajax_nopriv_get_ajax_single_admin_analytics', array(
                        $this,
                        'get_ajax_single_admin_analytics'
                    ));

            add_action( 'wp_ajax_get_ajax_single_admin_analytics', array(
                        $this,
                        'get_ajax_single_admin_analytics'
                    ));

            if( get_option( 'analytify_disable_front') == 0 ) {

                add_filter( 'the_content', array(
                            $this,
                            'get_single_front_analytics'
                ));        
            }

            add_action ( 'wp_ajax_pa_get_online_data', array (
                        $this,
                        'pa_realtime_data_get'
                    ));

            /*
             *   Grab online visitors for frontend widget
             */
            add_action ( 'wp_ajax_nopriv_pa_get_online_data', array (
                        $this,
                        'pa_realtime_data_get'
                    ));

            //add_action ('ga_ecommerce_js', array($this, 'add_ga_ecommerce_js'));
            /* 
             * load Analytics under the EDIT POST Screen
             * add action runs only for admin section and load metabox.
            */

            if ( is_admin() ) {
                add_action( 'load-post.php', array(
                            $this,
                            'load_metaboxes'
                        ));
            }

            // Show welcome message when user activate plugin.
            if ( get_option( 'pa_welcome_message' ) == 0 ) {
                    
                add_action( 'admin_print_footer_scripts', array( 
                            $this, 
                            'pa_welcome_message' 
                           ) );
            }

        }

        /**
         * Internationalization
         *
         * @access      public
         * @since       1.2.2
         * @return      void
         */
        public function load_textdomain() {

            $plugin_dir = basename( dirname(__FILE__) );
            load_plugin_textdomain( 'wp-analytify', false , $plugin_dir . '/lang/');
        }


        /*
         * Show licensey key inputs
         */
        public function add_edd_license_key( $license_key ) {
          
            ob_start();
            ?>
            
            <tr valign="top"> 
                <th scope="row" valign="top">
                    <?php _e('License Key', 'wp-analytify'); ?>
                </th>
                <td>
                    <input id="analytify_license_key" name="analytify_license_key" type="text" class="regular-text" value="<?php esc_attr_e( $license ); ?>" />
                    <label class="description" for="analytify_license_key"><?php _e('Enter your license key'); ?></label>
                </td>
            </tr>

            <?php 
            $license_key .= ob_get_contents();
            ob_clean();

            return $license_key;
        }

        /*
         * Show analytics sections under the posts/pages in the metabox.
         */

        function load_metaboxes() {

            add_action( 'add_meta_boxes', array(
                        $this,
                        'show_admin_single_analytics_add_metabox'
            ));
        }

        /* 
         * Show metabox under each Post type to display Analytics of single post/page in wp-admin
         */
        public function show_admin_single_analytics_add_metabox() {


            $post_types = get_option( 'analytify_posts_stats' );

            // Don't load boxes/sections if no any post type is selected.
            if( !empty($post_types))
            foreach ( $post_types as $post_type ) {
                    
                add_meta_box('pa-single-admin-analytics', // $id
                        'Google Analytics of above page.', // $title
                        array(
                            'WP_Analytify',
                            'show_admin_single_analytics'
                        ), // $callback
                        
                        $post_type, // $posts
                        'normal',   // $context
                        'high'      // $priority
                    ); 
            } //$post_types as $post_type
        }

        /* 
         * Show Analytics of single post/page in wp-admin under EDIT screen.
         */
        public static function show_admin_single_analytics() {

            global $post;

            $back_exclude_posts = explode(',', get_option( 'post_analytics_exclude_posts_back' ));

            if ( is_array( $back_exclude_posts ) ) {
                            
                if ( in_array( $post->ID, $back_exclude_posts ) ) {

                    _e('This post is excluded and will NOT show Analytics.');
                                
                    return;
                }
            }

            $urlPost = '';
            $wp_analytify  = new WP_Analytify();
            $urlPost = parse_url( get_permalink( $post->ID ) );
            $start_date = ''; $end_date = ''; $urlpost = '' ;
            $is_access_level = get_option( 'post_analytics_access_back' );

            if( $wp_analytify->pa_check_roles( $is_access_level ) ){ ?>

                <div class="pa-filter">
                    <table cellspacing="0" cellpadding="0" width="400">
                        <tbody>
                            <tr>
                                <td width="0">
                                    <input type="text" id="start_date" name="start_date">
                                </td>
                                <td width="0">
                                    <input type="text" id="end_date" name="end_date">
                                </td>
                                    <input type="hidden" name="urlpost" id="urlpost" value="<?php echo $urlPost['path']; ?>">
                                <td width="0">
                                    <input type="button" id="view_analytics" name="view_analytics" value="View Analytics" class="button-primary btn-green">
                                </td>
                           </tr>
                        </tbody>
                    </table>
                </div>
                <div class="loading" style="display:none">
                    <img src="<?php echo plugins_url('images/loading.gif', __FILE__);?>">
                </div>
                <div class="show-hide">
                        <?php $wp_analytify->get_single_admin_analytics( $start_date, $end_date, $post->ID, 0 ); ?>
                </div>
                <?php
            }
            else{
                echo _e( 'You are not allowed to see stats', 'wp-analytify' );
            }
        }

        /*
         * 
         */
        function analytify_shortcode_button() {

            if ( ! current_user_can( 'edit_posts' ) && ! current_user_can( 'edit_pages' ) ) {
                return;
            }

            if ( get_user_option( 'rich_editing' ) == 'true' ) {

                add_filter( 'mce_external_plugins', array( $this, 'analytify_stats_js' ) );
                add_filter( 'mce_buttons',          array( $this, 'register_analytify_button' ) );
            }
        }

        function analytify_stats_js( $plugin_array ) {

            $plugin_array['analytifystats'] = plugins_url( 'js/shortcode.js', __FILE__);
            return $plugin_array;
        }

        function register_analytify_button( $buttons ) {
            
            array_push( $buttons, "|", "analytifystats" );
            return $buttons;
        }

        /*
         *  Shortcodes implementation for front end
         */
        public function analytify_stats_shortcode( $atts, $content = null ) {
            
            if ( !wp_style_is( 'front-end-style', 'enqueued' ) ) {
                wp_enqueue_style( 'front-end-style', plugins_url( 'css/frontend_styles.css', __FILE__ ), false, ANALYTIFY_VERSION );            
            }

            global $post;
            $return = '';
            $filter = '';

            extract( shortcode_atts( array(
                                          'metrics'     => 'ga:sessions',
                                          'dimensions'  => '',
                                          'start_date'  => get_the_time('Y-m-d', $post->ID),
                                          'end_date'    => date('Y-m-d'),
                                          'sort'        => '',
                                          'filter'      => $filter,
                                          'max_results' => 6,
                                          'analytics_for' => 'current',
                                          'date_type'   => 'custom',
                                          'permission_view'=>''
                                        ),
                                    $atts ));

            /*
             *  Making transient string for cache
             */

            $transient_value = $metrics .'_' . $dimensions .'_' . $date_type .'_'. $start_date .'_'. $end_date .'_'. $sort .'_'. $filter .'_'. $max_results .'_'. $analytics_for .'_'. $permission_view;
            //echo $transient_value;
            /*
             * Handing ShortCode dates
             */

            if( $date_type != 'custom') {

                if( $date_type == 'today')
                    $start_date = date('Y-m-d');

                if( $date_type == '- 7 days');
                    $start_date = date( "Y-m-d", strtotime( $date_type) );

                if( $date_type == '- 15 days');
                    $start_date = date( "Y-m-d", strtotime( $date_type) );

                if( $date_type == '- 30 days');
                    $start_date = date( "Y-m-d", strtotime( $date_type) );

                if( $date_type == '- 1 days') {

                    $start_date = date( "Y-m-d", strtotime( $date_type) );
                    $end_date = date( "Y-m-d", strtotime( $date_type) );

                }
            }


            if( $analytics_for == 'current') {
                $u_post = parse_url( get_permalink( $post->ID ) );
                $filter = 'ga:pagePath==' . $u_post['path'] . '';
            }
            else{
                $filter = false;
            }

            if ( !empty( $dimensions ) )
                $is_dimensions = $dimensions;
            else
                $is_dimensions = false;

            $all_metrics    =   explode( ',', $metrics );
            $all_dimensions =   explode( ',', $dimensions );

            if ( empty( $sort )) {
               $is_sort = $all_metrics[0];
            }
            else{
                $is_sort = $sort;
            }

            // If post year is less than 2005, Make it to start from 2005

            if( get_the_time( 'Y', $post->ID ) < 2005 ) {

                $start_date = '2005-01-01';
            }

            $stats = get_transient( md5($transient_value) ) ;

            if( $stats === false ) {

                $stats = $this->wpa_get_analytics( 'single', $metrics, $start_date, $end_date, $is_dimensions, $is_sort, $filter, $max_results );
                
                set_transient(  md5($transient_value) , $stats, 60 * 60 * 2 );
            }

            $total          =   count( $all_metrics ) + count( $all_dimensions );

            $current_user   =   wp_get_current_user();
            $roles          =   $current_user->roles; 
            $role_to_show   =   explode(',', $permission_view);

            if( $current_user->ID == 0 )
                $current_role   =   'everyone';
            else
                $current_role   =   $roles[0];

            // Comment of start and end date for analytics.
            $return .= ' <!-- Fetching Analytics from '. $start_date .' to '. $end_date .' -->';

            if( ! empty( $stats["rows"] ) ){

                if( empty( $dimensions ) ){

                    if( $permission_view == "" || in_array( $current_role, $role_to_show )){
                        
                        $return             .= "<div class='shortcode-table'><table> ";
                        
                        for ( $i = 0; $i < count( $all_metrics ) ; $i++ ) { 
                            
                            $title         = $all_metrics[$i];
                            $matrics_title = explode( ':', $title );
                            
                            if( ! is_numeric( $stats->totalsForAllResults[$all_metrics[$i]] ))
                                $return       .= $stats->totalsForAllResults[$all_metrics[$i]];
                            else
                                $return       .= $this->wpa_number_format( $stats->totalsForAllResults[$all_metrics[$i]] ) . "<br/>";

                            $return       .= "<br/>";

                        }

                        $return .= "</table></div>";
                    }
                }
                else
                {
                    
                    if ( $permission_view == "" || in_array( $current_role, $role_to_show )) {
                        
                        $return             .= "<div class='shortcode-table'><table> ";
                        $query_dimensions    = explode( ',', $stats['query']->dimensions); 
                            
                            for ( $i = 0; $i < count( $query_dimensions ) ; $i++ ) { 
                                
                                if( $query_dimensions[ $i ] == 'ga:userType' ){
                                    //Change texts here for dimensions
                                    //$query_dimensions[ $i ] = 'Players Type';
                                }

                                $return .= "<th>" . str_replace( 'ga:', '', $query_dimensions[ $i ]) . "</th> ";
                            }   
                            
                            for ( $i = 0; $i < count( $all_metrics ) ; $i++ ) { 


                                if( $stats['query']->metrics[ $i ] == 'ga:users') {
                                    //Change texts here for metrics
                                    //$stats['query']->metrics[ $i ] = 'Players';
                                }


                                $return .= "<th>" . str_replace( 'ga:', '', $stats['query']->metrics[ $i ]) . "</th> ";
                            }

                            $return .= "<tr rowspan='" . $max_results . "'>";

                            for ( $i = 0; $i < $total; $i++ ) { 
                                    
                                    foreach ( $stats["rows"] as $b_stat ) {
                                            
                                            $return .= "<tr rowspan='" . $max_results . "'>";
                                                
                                                for ( $i = 0; $i < count( $b_stat ) ; $i++) {

                                                    // Add Strings here for dimension rows
                                                    //$b_stat[ $i ] = str_replace(array('New Visitor', 'Returning Visitor'), array('New Player','Returning Player'), $b_stat[ $i ]) ;
                                                    if( ! is_numeric($b_stat[ $i ]))
                                                        $return .= "<td>" . $b_stat[ $i ] . "</td>";
                                                    else 
                                                        $return .= "<td>" . $this->wpa_number_format($b_stat[ $i ]) . "</td>";
                                                }
                                            $return .= "</tr>";
                                        }
                                }
                        
                        $return .= "</table></div>";
                       
                    }
                }
            }

            return $return;
        }

        function analytify_mce_css( $mce_css ) {

            if ( ! empty( $mce_css ) ){
                
                $mce_css .= ',';
            }

                $mce_css .= plugins_url( 'css/wp-analytify-editor.css', __FILE__ );
                return $mce_css;
        }

        /*
         * View of Shortcode window
         */
        public function analytify_shortcode_view () { 

            include_once( ANALYTIFY_ROOT_PATH . '/inc/shortcode.php' );  
            die();
        }

        // Add Google Analytics JS code
        public function analytify_add_analytics_code() {

            global $current_user;

            $roles = $current_user->roles;

            if ( isset( $roles[0] ) and get_option( 'display_tracking_code' ) and in_array( $roles[0], get_option( 'display_tracking_code' ) )) {

            }
            else{

                echo '<!-- This code is added by Analytify v - ' . ANALYTIFY_VERSION . ' http://wp-analytify.com/downloads/analytify-wordpress-plugin/ !--> ';

                if ( get_option( 'analytify_tracking_code' ) == 'universal' ) { ?>

                    <script>
                        (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
                          (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
                          m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
                          })
                        (window,document,'script','//www.google-analytics.com/analytics.js','ga');
                        ga('create', '<?php echo get_option( "webPropertyId" );?>', 'auto');

                        <?php
                            
                            if(has_action('ga_ecommerce_js'))
                                do_action('ga_ecommerce_js');
                            else
                                echo "ga('send', 'pageview');";
                            ?>
                    </script>
                <?php
                }

                if ( get_option( 'analytify_tracking_code' ) == 'ga' ) { ?>

                    <script type="text/javascript">//<![CDATA[
                        var _gaq = _gaq || [];
                        _gaq.push(['_setAccount', '<?php echo get_option( "webPropertyId" );?>']);
                        _gaq.push(['_trackPageview']);
                        (function () {
                            var ga = document.createElement('script');
                            ga.type = 'text/javascript';
                            ga.async = true;
                            ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
                            var s = document.getElementsByTagName('script')[0];
                            s.parentNode.insertBefore(ga, s);
                        })();
                        //]]>
                    </script>

                <?php
                }

                echo '<!-- This code is added by Analytify  v - ' . ANALYTIFY_VERSION . ' !-->';
            }
        }

        // Get RealTime statistics.
        function pa_realtime_data_get() {
                
            if (! isset( $_REQUEST['pa_security'] ) OR ! wp_verify_nonce( $_REQUEST['pa_security'] , 'pa_get_online_data' ) ) {
                return;
            }
                
            if (! function_exists( 'curl_version' ) ) {
                die();
            }

            print_r( stripslashes( json_encode( $this->pa_realtime_data( get_option( 'pt_webprofile_dashboard' ) ) ) ) ); 

            die();
        }

        /**
        * Add a link to the settings page to the plugins list
        */
        public function pa_plugin_links( $links, $file ) {

                static $this_plugin;
                
                if ( empty( $this_plugin ) ){ 
                    
                    $this_plugin = 'wp-analytify-pro/wp-analytify-pro.php';
                }

                if ( $file == $this_plugin ) {
                    
                    $settings_link = '<a href="' . admin_url("admin.php?page=analytify-settings") . '">' . __( 'Settings', 'wp-analytify' ) . '</a> | <a href="' . admin_url("admin.php?page=analytify-dashboard") . '">' . __( 'Dashboard', 'wp-analytify' ) . '</a> | <a href="' . admin_url( 'index.php?page=wp-analytify-getting-started' ) . '">' . esc_html__( 'Help', 'wp-analytify' );
                    array_unshift( $links, $settings_link );
                }
                
                return $links;
        }

        /**
         * Plugin row meta links
         *
         * @since 1.1
         * @param array $input already defined meta links
         * @param string $file plugin file path and name being processed
         * @return array $input
         */
        function analytify_plugin_row_meta( $input, $file ) {
            if ( $file != 'wp-analytify-pro/wp-analytify-pro.php' )
                return $input;

            $links = array(
                '<a href="' . admin_url( 'index.php?page=wp-analytify-getting-started' ) . '">' . esc_html__( 'Getting Started', 'edd' ) . '</a>',
                '<a href="http://wp-analytify.com/add-ons/">' . esc_html__( 'Add Ons', 'edd' ) . '</a>',
            );

            $input = array_merge( $input, $links );

            return $input;
        }


        /**
         * Display warning if profiles are not selected.
         */
        public function pa_check_warnings(){
                
            add_action( 'admin_footer', array( 
                        &$this, 
                        'profile_warning' 
                    ));
        }

        /**
         * Get current screen details
         */
        public static function pa_page_file_path() {
        
            $screen = get_current_screen();
           
            if ( strpos( $screen->base, 'analytify-settings' ) !== false ) {
                include_once( ANALYTIFY_ROOT_PATH . '/inc/options-settings.php' );
            } 
            else if ( strpos( $screen->base, 'analytify-campaigns' ) !== false ) {
                include_once( ANALYTIFY_ROOT_PATH . '/inc/page-campaigns.php' );
            } 
            else {
                include_once( ANALYTIFY_ROOT_PATH . '/inc/analytics-dashboard.php' );
            }
        }

        /**
         * Styling: loading stylesheets for the plugin.
         */
        public function pa_styles( $page ) {
                
                wp_enqueue_style( 'wp-analytify-style', plugins_url('css/wp-analytify-style.css', __FILE__));

               // wp_enqueue_style( 'ui-css', plugins_url('jquery-ui-theme/jquery-ui.css', __FILE__));
                wp_enqueue_style( 'chosen', plugins_url('css/chosen.css', __FILE__));
               // wp_enqueue_style( 'jquery-ui-tooltip-css', plugins_url('css/jquery.ui.tooltip.html.css', __FILE__) );

                if ( get_option( 'pa_welcome_message' ) == '0' ) {
                    
                    wp_enqueue_style( 'wp-pointer' );
                
                }
        }

        public function pa_front_styles( $page ) {
            
            if( get_option( 'analytify_disable_front') == 0 ) {

                //wp_enqueue_style( 'analytify-bootstrap-style', plugins_url('css/bootstrap.min.css', __FILE__),false,ANALYTIFY_VERSION);
                //wp_enqueue_style( 'analytify-font-awesome', plugins_url('css/font-awesome.min.css', __FILE__),false,ANALYTIFY_VERSION);
                wp_enqueue_style( 'front-end-style', plugins_url('css/frontend_styles.css', __FILE__),false,ANALYTIFY_VERSION);            
            }
        }

        /**
         * Loading scripts js for the plugin.
         */
        public function pa_scripts( $page ) {

            wp_enqueue_script ( 'jquery' );
            wp_enqueue_script ( 'charts_api_js', 'https://www.google.com/jsapi', false, ANALYTIFY_VERSION );
            wp_enqueue_script ( 'chosen-js', plugins_url('js/chosen.jquery.js', __FILE__), false, ANALYTIFY_VERSION );
            wp_enqueue_script ( 'script-js', plugins_url('js/wp-analytify.js', __FILE__), false, ANALYTIFY_VERSION );
            wp_enqueue_script ( 'jquery-ui-tooltip' );
            wp_enqueue_script ( 'jquery-ui-datepicker');
                
            if ( get_option( 'pa_welcome_message' ) == '0' ) {
                 
                wp_enqueue_script( 'wp-pointer' );
            }   
        }

        /**
         * Loading scripts js for the plugin.
         */
        public function pa_front_scripts( $page ) {
            
            if( get_option( 'analytify_disable_front') == 0 ){

                wp_enqueue_script ('jquery');
                //wp_enqueue_script ('analytify-bootstrap', plugins_url('js/bootstrap.min.js', __FILE__), false, ANALYTIFY_VERSION);
                wp_enqueue_script ('analytify-classie', plugins_url('js/classie.js', __FILE__), false, ANALYTIFY_VERSION);
                wp_enqueue_script ('analytify-selectfx', plugins_url('js/selectFx.js', __FILE__), false, ANALYTIFY_VERSION);
                wp_enqueue_script ('analytify-script', plugins_url('js/script.js', __FILE__), false, ANALYTIFY_VERSION);
                wp_localize_script( 'analytify-script', 'ajax_object',
                                                                    array( 'ajax_url' => admin_url( 'admin-ajax.php' ), 'we_value' => 1234 ) );

            }
        }

        /** 
         * Create Analytics menu at the left side of dashboard
         */
        public static function wpa_add_menu() {

    /*        $wp_analytify  = new WP_Analytify();
            if( $wp_analytify->pa_check_roles( get_option( 'post_analytics_access_back' ) ) ) {*/

            add_menu_page( ANALYTIFY_NICK, 'Analytify', 'publish_pages', 'analytify-dashboard', array(
                              __CLASS__,
                             'pa_page_file_path'
                            ), plugins_url('images/wp-analytics-logo.png', __FILE__),'2.1.9');

            add_submenu_page( 'analytify-dashboard', ANALYTIFY_NICK . ' Dashboard', ' Dashboard', 'publish_pages', 'analytify-dashboard', array(
                                  __CLASS__,
                                 'pa_page_file_path'
                                ));

           /* }*/

            add_submenu_page( 'analytify-dashboard', ANALYTIFY_NICK . ' Campaign', ' Campaigns', 'manage_options', 'analytify-campaigns', array(
                                  __CLASS__,
                                 'pa_page_file_path'
                                ));

            add_submenu_page( 'analytify-dashboard', ANALYTIFY_NICK . ' Settings', '<b style="color:#f9845b">Settings</b>', 'manage_options', 'analytify-settings', array(
                                  __CLASS__,
                                 'pa_page_file_path'
                                ));
        }

        /**
         * Creating tabs for settings
         * @since 1.0
         */

        public function pa_settings_tabs( $current = 'authentication' ) {
                
                $tabs = array( 'authentication' =>  'Authentication',
                                'profile'       =>  'Profile',
                                'front'         =>  'Front' ,
                                'admin'         =>  'Admin',  
                                'license'       =>  'License'  
                        );

                echo '<div class="left-area">';

                echo '<div id="icon-themes" class="icon32"><br></div>';
                echo '<h2 class="nav-tab-wrapper">';

                foreach( $tabs as $tab => $name ) {

                    $class = ( $tab == $current ) ? ' nav-tab-active' : '';
                    echo "<a class='nav-tab$class' href='?page=analytify-settings&tab=$tab'>$name</a>";
                }

                echo '</h2>';
        }

        /**
         * Get profiles from user Google Analytics account profiles.
         */

        public function pt_get_analytics_accounts () {

            try {

                if( get_option( 'pa_google_token' ) != '' ) {
                    $profiles = $this->service->management_profiles->listManagementProfiles( "~all", "~all" );
                    return $profiles;
                }
                else{
                        echo '<br /><p class="description">' . __( 'You must authenticate to access your web profiles.', 'wp-analytify' ) . '</p>';
                }

            }

            catch (Exception $e) {
                echo '<br /><strong> oOps, Something went wrong! </strong><br />' . $e->getMessage() . '<br /><br /> Try to <a href=\'?page=analytify-settings&tab=authentication\' title="Reset">Reset</a> Authentication.';
            }

        }

        public function pa_setting_url() {
            
            return admin_url('admin.php?page=analytify-settings');
        
        }


        public function pt_save_data( $key_google_token ) {

            update_option( 'post_analytics_token', $key_google_token );
            $this->pa_connect();

            return true;
        }

        /**
         * Warning messages.
         */
        public function profile_warning() {

                $profile_id     =   get_option( "pt_webprofile" );
                $acces_token    =   get_option( "post_analytics_token" );

                if (! isset( $acces_token ) || empty( $acces_token )) {
                   
                   echo "<div id='message' class='error'><p><strong>" . __( "Analytify is not active. Please <a href='" . menu_page_url ( 'analytify-settings', false ) ."'>Authenticate</a> in order to get started using this plugin.", 'wp-analytify' )."</p></div>"; 
                }
                else{
                    
                    if (! isset( $profile_id ) || empty( $profile_id )){
                        echo '<div class="error"><p><strong>' . __( 'Google Analytics Profile is not set. Set the <a href="' . menu_page_url ( 'analytify-settings', false ) . '&tab=profile">Profile</a> ', 'wp-analytify' ) . '</p></div>';
                    }
                }
        }


        public function get_single_front_analytics( $content ) {
            
            global $post, $wp_analytify;

            $front_access = get_option( 'post_analytics_access' );

            if ( is_single() || is_page() ) {
                
                $post_type = get_post_type( $post->ID );
                
                if( strlen( get_option( 'analytify_posts_stats_front' ) < 3) ) {
                    return $content;
                }

                if( is_array( get_option( 'analytify_posts_stats_front' )) and !in_array( $post_type, get_option( 'analytify_posts_stats_front' ) ) ) {

                    return $content;
                }

                $front_exclude_posts_arr = explode( ',', get_option( 'post_analytics_exclude_posts_front' ));

                if ( is_array( $front_exclude_posts_arr ) ) {

                    if ( in_array( get_the_ID(), $front_exclude_posts_arr ) ) {

                        return $content;
                    }
                }

                // Showing stats to guests
                if ( $front_access[0] == 'every-one' || $this->pa_check_roles( $front_access )) {
                    
                    $post_analytics_settings_front = array();
                    $post_analytics_settings_front = get_option( 'post_analytics_settings_front' );
                  
                    $urlPost =  parse_url( get_permalink( $post->ID ) );
                
                    if ( $urlPost['host'] == 'localhost' ) 
                        $filter = 'ga:pagePath==/'; //.$u_post['path'];
                    else 
                        $filter = 'ga:pagePath==' .$urlPost['path']. '';  


                    if( get_the_time('Y', $post->ID) < 2005 ) {

                        $start_date = '2005-01-01';
                    }
                    else {

                        $start_date = get_the_time('Y-m-d', $post->ID);   
                    }

                    $end_date = date('Y-m-d');

                    ob_start();

                    include_once ANALYTIFY_ROOT_PATH . '/inc/front-menus.php';

                    if(! empty( $post_analytics_settings_front )) {

                            if (is_array( $post_analytics_settings_front )) {

                                if (in_array( 'show-overall-front', $post_analytics_settings_front )) {

                                    $stats = get_transient( md5('show-overall-front' . $filter) ) ;
                                    if( $stats === false ) {
                                        $stats = $this->wpa_get_analytics( 'single', 'ga:sessions,ga:bounces,ga:newUsers,ga:entrances,ga:pageviews,ga:sessionDuration,ga:avgSessionDuration,ga:users',$start_date, $end_date, false, false, $filter);
                                        set_transient(  md5('show-overall-front' . $filter) , $stats, 60 * 60 * 20 );
                                    }

                                    if ( isset( $stats->totalsForAllResults ) ) {

                                        include_once ANALYTIFY_ROOT_PATH . '/views/front/general-stats.php'; 
                                        pa_include_general( $this, $stats);
                                    }
                                }
                            }

                            if (is_array( $post_analytics_settings_front )) {
                                if (in_array( 'show-country-front', $post_analytics_settings_front )){

                                    $country_stats = get_transient( md5('show-country-front' . $filter) ) ;
                                    if( $country_stats === false ) {
                                        $country_stats = $this->wpa_get_analytics( 'single', 'ga:sessions', $start_date, $end_date, 'ga:country', '-ga:sessions', $filter,5);
                                        set_transient(  md5('show-country-front' . $filter) , $country_stats, 60 * 60 * 20 );
                                    }

                                    if ( isset( $country_stats->totalsForAllResults ) ) { 
                                        include_once ANALYTIFY_ROOT_PATH . '/views/front/country-stats.php'; 
                                        pa_include_country( $this, $country_stats );
                                    }
                                }
                            }

                            if (is_array( $post_analytics_settings_front )) {
                                if (in_array( 'show-city-front', $post_analytics_settings_front )){

                                    $city_stats = get_transient( md5('show-city-front' . $filter) ) ;
                                    if( $city_stats === false ) {
                                        $city_stats = $this->wpa_get_analytics( 'single', 'ga:sessions', $start_date, $end_date, 'ga:city', '-ga:sessions', $filter, 5);
                                        set_transient(  md5('show-city-front' . $filter) , $city_stats, 60 * 60 * 20 );
                                    }
                                    
                                    if ( isset( $city_stats->totalsForAllResults ) ) { 
                                        include_once ANALYTIFY_ROOT_PATH . '/views/front/city-stats.php'; 
                                        pa_include_city( $this, $city_stats );
                                    }
                                }
                            }
                           

                            if (is_array( $post_analytics_settings_front )) {
                                    if (in_array( 'show-keywords-front', $post_analytics_settings_front)){

                                        $keyword_stats = get_transient( md5('show-keywords-front' . $filter) ) ;
                                        if( $keyword_stats === false ) {
                                            $keyword_stats = $this->wpa_get_analytics( 'single', 'ga:sessions', $start_date, $end_date, 'ga:keyword', '-ga:sessions',$filter,10 );
                                            set_transient(  md5('show-keywords-front' . $filter) , $keyword_stats, 60 * 60 * 20 );
                                        }

                                        if ( isset( $keyword_stats->totalsForAllResults ) ) {
                                            include_once ANALYTIFY_ROOT_PATH . '/views/front/keywords-stats.php'; 
                                            pa_include_keywords( $this, $keyword_stats );
                                        }
                                    }
                            }

                            if (is_array($post_analytics_settings_front)) {
                                if (in_array( 'show-social-front', $post_analytics_settings_front )){
        
                                        $social_stats = get_transient( md5('show-social-front' . $filter) ) ;
                                        if( $social_stats === false ) {
                                            $social_stats = $this->wpa_get_analytics( 'single', 'ga:sessions', $start_date, $end_date, 'ga:socialNetwork', '-ga:sessions',$filter, 10);
                                            set_transient(  md5('show-social-front' . $filter) , $social_stats, 60 * 60 * 20 );
                                        }

                                        if ( isset( $social_stats->totalsForAllResults ) ) { 
                                            include_once ANALYTIFY_ROOT_PATH . '/views/front/social-stats.php';
                                            pa_include_social( $this, $social_stats );
                                        } 
                                }
                            }

                            if (is_array($post_analytics_settings_front)) {
                                if (in_array( 'show-browser-front', $post_analytics_settings_front )){

                                    $browser_stats = get_transient( md5('show-browser-front' . $filter) ) ;
                                    if( $browser_stats === false ) {
                                        $browser_stats = $this->wpa_get_analytics( 'single', 'ga:sessions', $start_date, $end_date, 'ga:browser,ga:operatingSystem', '-ga:sessions',$filter,5 );
                                        set_transient(  md5('show-browser-front' . $filter) , $browser_stats, 60 * 60 * 20 );
                                    }

                                    if (isset( $browser_stats->totalsForAllResults ) ) {
                                        include_once ANALYTIFY_ROOT_PATH . '/views/front/browser-stats.php'; 
                                        pa_include_browser( $this, $browser_stats );
                                    }
                                }
                            }

                            if (is_array($post_analytics_settings_front)) {
                                if (in_array( 'show-os-front', $post_analytics_settings_front )){
                                    
                                    $os_stats = get_transient( md5('show-os-front' . $filter) ) ;
                                    if( $os_stats === false ) {
                                        $os_stats = $this->wpa_get_analytics( 'single', 'ga:sessions', $start_date, $end_date, 'ga:operatingSystem,ga:operatingSystemVersion', '-ga:sessions', $filter, 5);
                                        set_transient(  md5('show-os-front' . $filter) , $os_stats, 60 * 60 * 20 );
                                    }

                                    if (isset( $os_stats->totalsForAllResults ) ) {
                                        include_once ANALYTIFY_ROOT_PATH . '/views/front/os-stats.php'; 
                                        pa_include_operating( $this, $os_stats );
                                        
                                    }
                                }
                            }

                            if (is_array($post_analytics_settings_front)) {
                                if (in_array( 'show-mobile-front', $post_analytics_settings_front )){
                                    
                                    $mobile_stats = get_transient( md5('show-mobile-front' . $filter) ) ;
                                    if( $mobile_stats === false ) {
                                        $mobile_stats = $this->wpa_get_analytics( 'single', 'ga:sessions', $start_date, $end_date, 'ga:mobileDeviceInfo', '-ga:sessions', $filter, 5);
                                        set_transient(  md5('show-mobile-front' . $filter) , $mobile_stats, 60 * 60 * 20 );
                                    }

                                    if (isset( $mobile_stats->totalsForAllResults ) ) {
                                        include_once ANALYTIFY_ROOT_PATH . '/views/front/mobile-stats.php'; 
                                        pa_include_mobile( $this, $mobile_stats );
                                    }
                                }
                            }

                            if (is_array($post_analytics_settings_front)) {
                                if (in_array( 'show-referrer-front', $post_analytics_settings_front )) {    

                                    $referr_stats = get_transient( md5('show-referrer-front' . $filter) ) ;
                                    if( $referr_stats === false ) {
                                        $referr_stats = $this->wpa_get_analytics( 'single', 'ga:sessions', $start_date, $end_date, 'ga:source,ga:medium', '-ga:sessions',$filter,10 );
                                        set_transient(  md5('show-referrer-front' . $filter) , $referr_stats, 60 * 60 * 20 );
                                    }

                                    
                                    if ( isset( $referr_stats->totalsForAllResults ) ) {
                                        include_once ANALYTIFY_ROOT_PATH . '/views/front/referrers-stats.php'; 
                                        pa_include_referrers( $this, $referr_stats );
                                    }
                                }
                            }
                    }

                    $content .= ob_get_contents();
                    ob_get_clean();
                }

            }

            return $content;

        }

        /*
         * get the Analytics data from ajax() call
         *
         */

        public function get_ajax_single_admin_analytics() {

            $startDate = '';
            $endDate   = '';
            $postID    = 0 ;
            $startDate = $_POST['start_date'];
            $endDate   = $_POST['end_date'];
            $postID    = $_POST['post_id'];
            $this->get_single_admin_analytics( $startDate, $endDate, $postID, 1 );

            die();
        }

        /*
         * get the Analytics data for wp-admin posts/pages.
         * 
         */
        public function get_single_admin_analytics( $start_date = '', $end_date = '', $postID = 0, $ajax = 0 ) {

            global $post;
                
                //$urlPost = parse_url( get_permalink( $post->ID ) );
                
            if ( $postID == 0 ) {
                $u_post = '/'; //$urlPost['path'];
            }
            else{
                $u_post = parse_url( get_permalink( $postID ) );
            }

            if ( $u_post['host'] == 'localhost' )
                $filter = 'ga:pagePath==/'; //.$u_post['path'];
            else
               $filter = 'ga:pagePath==' .$u_post['path']. '';

            if ( $start_date == '' ) {
                
                $s_date = get_the_time('Y-m-d', $post->ID);
                if(get_the_time('Y', $post->ID) < 2005){
                    $s_date = '2005-01-01';
                }
            }
            else{
                $s_date = $start_date;
            }

            if ( $end_date == '' ) {
                $e_date = date('Y-m-d');
            }   
            else{
                    $e_date = $end_date;
            }

            $show_settings = array();
            $show_settings = get_option('post_analytics_settings_back');
                
            // Stop here, if user has disable backend analytics i.e OFF
            if ( get_option( 'post_analytics_disable_back' ) == 1 and $ajax == 0) {
                return;
            }

            
            echo '<p> Displaying Analytics of this page from ' . date("jS F, Y", strtotime($s_date)) . ' to '. date("jS F, Y", strtotime($e_date)) . '</p>';
                
            if( !empty( $show_settings )){

                if (is_array( $show_settings )){
                        
                    if (in_array( 'show-overall-back', $show_settings )) { 

                        $stats = $this->pa_get_analytics( 'ga:sessions,ga:bounces,ga:newUsers,ga:entrances,ga:pageviews,ga:sessionDuration,ga:avgSessionDuration,ga:users',$s_date, $e_date, false, false, $filter);
                            
                        if ( isset( $stats->totalsForAllResults ) ) {
                                
                            include_once ANALYTIFY_ROOT_PATH . '/views/admin/single-general-stats.php'; 
                            wpa_include_single_general( $this, $stats);                      
                        } 
                    }
                }

                if (is_array( $show_settings )){
                            if (in_array( 'show-country-back', $show_settings )){
                                $country_stats = $this->pa_get_analytics( 'ga:sessions', $s_date, $e_date, 'ga:country', '-ga:sessions', $filter,5);
                                if ( isset( $country_stats->totalsForAllResults ) ) { 
                                    include_once ANALYTIFY_ROOT_PATH . '/views/admin/country-stats.php'; 
                                    pa_include_country( $this, $country_stats );
                                }
                            }
                }

                if (is_array( $show_settings )){
                            if (in_array( 'show-city-back', $show_settings )){
                                $city_stats = $this->pa_get_analytics( 'ga:sessions', $s_date, $e_date, 'ga:city', '-ga:sessions', $filter, 5);
                                if ( isset( $city_stats->totalsForAllResults ) ) { 
                                    include_once ANALYTIFY_ROOT_PATH . '/views/admin/city-stats.php'; 
                                    pa_include_city( $this, $city_stats );
                                }
                            }
                }
                       

                if (is_array( $show_settings )){
                                if (in_array( 'show-keywords-back', $show_settings)){      
                                $keyword_stats = $this->pa_get_analytics( 'ga:sessions', $s_date, $e_date, 'ga:keyword', '-ga:sessions',$filter,10 );
                                    if ( isset( $keyword_stats->totalsForAllResults ) ) {
                                        include_once ANALYTIFY_ROOT_PATH . '/views/admin/keywords-stats.php'; 
                                        pa_include_keywords( $this, $keyword_stats );
                                    }
                                }
                }
        
                if (is_array($show_settings)){
                            if (in_array( 'show-social-back', $show_settings )){       
                                $social_stats = $this->pa_get_analytics( 'ga:sessions', $s_date, $e_date, 'ga:socialNetwork', 'ga:sessions',$filter, 10);
                                    if ( isset( $social_stats->totalsForAllResults ) ) { 
                                        include_once ANALYTIFY_ROOT_PATH . '/views/admin/social-stats.php';
                                        pa_include_social( $this, $social_stats );
                                    } 
                            }
                }
        
                if (is_array($show_settings)){
                            if (in_array( 'show-browser-back', $show_settings )){     
                                $browser_stats = $this->pa_get_analytics( 'ga:sessions', $s_date, $e_date, 'ga:browser,ga:operatingSystem', '-ga:sessions',$filter,5 );
                                    if (isset( $browser_stats->totalsForAllResults ) ) {
                                        include_once ANALYTIFY_ROOT_PATH . '/views/admin/browser-stats.php'; 
                                        pa_include_browser( $this, $browser_stats );
                                    
                            }
                    }
                }

                if (is_array($show_settings)){
                            if (in_array( 'show-os-back', $show_settings )){
                                $os_stats = $this->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date, 'ga:operatingSystem,ga:operatingSystemVersion', '-ga:sessions', $filter, 5);
                                if (isset( $os_stats->totalsForAllResults ) ) {
                                    include_once ANALYTIFY_ROOT_PATH . '/views/admin/os-stats.php'; 
                                    pa_include_operating( $this, $os_stats );
                                    
                                }
                            }
                }

                if (is_array($show_settings)){
                                if (in_array( 'show-mobile-back', $show_settings )){
                                $mobile_stats = $this->pa_get_analytics_dashboard( 'ga:sessions', $s_date, $e_date, 'ga:mobileDeviceInfo', '-ga:sessions', $filter, 5);     
                                        if (isset( $mobile_stats->totalsForAllResults ) ) {
                                            include_once ANALYTIFY_ROOT_PATH . '/views/admin/mobile-stats.php'; 
                                            pa_include_mobile( $this, $mobile_stats );
                                        
                                }
                    }
                }

                if (is_array($show_settings)){
                            if (in_array( 'show-referrer-back', $show_settings )){    
                                $referr_stats = $this->pa_get_analytics( 'ga:sessions', $s_date, $e_date, 'ga:source,ga:medium', '-ga:sessions',$filter,10 );
                                if ( isset( $referr_stats->totalsForAllResults ) ) {
                                    include_once ANALYTIFY_ROOT_PATH . '/views/admin/referrers-stats.php'; 
                                    pa_include_referrers( $this, $referr_stats );
                                }
                            }
                }
        
                if (is_array( $show_settings )){
                            if (in_array( 'show-pages-back', $show_settings )){    
                                $page_stats = $this->pa_get_analytics( 'ga:entrances,ga:pageviews,ga:exits', $s_date, $e_date, 'ga:PagePath', '-ga:exits', $filter, 5 );
                                if ( isset( $page_stats->totalsForAllResults ) ) {
                                    include_once ANALYTIFY_ROOT_PATH . '/views/admin/single-pages-stats.php'; 
                                    pa_single_pages_stats( $this, $page_stats );
                                }
                            }
                }
            }
            else{
                
                $stats = $this->pa_get_analytics( 'ga:sessions,ga:bounces,ga:newUsers,ga:entrances,ga:pageviews,ga:sessionDuration,ga:avgSessionDuration,ga:users',$s_date, $e_date, false, false, $filter );
                
                if ( isset( $stats->totalsForAllResults ) ) {
                    include_once ANALYTIFY_ROOT_PATH . '/views/admin/general-stats.php'; 
                    wpa_include_single_general( $this, $stats );
                } 
            }
        }

        
        /*
         * Pretty numbers
         */
        function wpa_pretty_numbers( $num ) {

            return round(($num/1000),2).'k';
        }

        /*
         * format numbers
         */
        function wpa_number_format( $num ) {

            return number_format($num);
        }

        /*
         * Pretty time to display
         */
        function pa_pretty_time( $time ) {

                // Check if numeric
                if ( is_numeric($time) ) {

                    $value = array(
                        "years" => '00',
                        "days" => '00',
                        "hours" => '',
                        "minutes" => '',
                        "seconds" => ''
                    );
                    
                    if ($time >= 31556926) {
                        $value["years"] = floor($time / 31556926);
                        $time           = ($time % 31556926);
                    } //$time >= 31556926

                    if ($time >= 86400)
                        {
                        $value["days"] = floor($time / 86400);
                        $time          = ($time % 86400);
                        } //$time >= 86400
                    if ($time >= 3600)
                        {
                        $value["hours"] = str_pad(floor($time / 3600), 1, 0, STR_PAD_LEFT);
                        $time           = ($time % 3600);
                        } //$time >= 3600
                    if ($time >= 60)
                        {
                        $value["minutes"] = str_pad(floor($time / 60), 1, 0, STR_PAD_LEFT);
                        $time             = ($time % 60);
                        } //$time >= 60
                        $value["seconds"] = str_pad(floor($time), 1, 0, STR_PAD_LEFT);
                    # Get the hour:minute:second version
                    if($value['hours']!=''){
                        $attach_hours='<sub>h</sub> ';
                    }
                    if($value['minutes']!=''){
                        $attach_min='<sub>min</sub> ';
                    }
                    if($value['seconds']!=''){
                        $attach_sec='<sub>sec</sub>';
                    }
                    return $value['hours'] .@$attach_hours. $value['minutes'] .@$attach_min. $value['seconds'].$attach_sec;
                    //return $value['hours'] . ':' . $value['minutes'] . ':' . $value['seconds'];
                    } //is_numeric($time)
                else
                    {
                    return false;
                    }
        }


        public function pa_check_roles( $access_level ) {
                
            if ( is_user_logged_in () && isset ( $access_level ) ) {
                    
                global $current_user;
                $roles = $current_user->roles;

                    /*if ( ( current_user_can ( 'manage_options' ) ) ) {
                        
                        return true;
                    }*/

                if ( in_array ( $roles[0], $access_level ) ) {
                        
                    return true;
                }
                else {
                        
                    return false;
                }
            }
        }

        public function pa_realtime() {
                
                $code = '
                    <script type="text/javascript">
                    function onlyUniqueValues(value, index, self) {
                        return self.indexOf(value) === index;
                     }
            
                    function countvisits(data, searchvalue) {
                        var count = 0;
                        if(data["rows"]){
                        for ( var i = 0; i < data["rows"].length; i = i + 1 ) {
                            if (jQuery.inArray(searchvalue, data["rows"][ i ])>-1){
                                count += parseInt(data["rows"][ i ][6]);
                            }
                        }
                    }
                        return count;
                     }

                    function pa_generatetooltip(data) {
                        var count = 0;
                        var table = "";
                        for ( var i = 0; i < data.length; i = i + 1 ) {
                                count += parseInt(data[ i ].count);
                                table += "<td>"+data[i].value+"</td><td class=\'pa-pgdetailsr\'>"+data[ i ].count+"</td></tr>";
                        };
                        if (count){
                            return("<table>"+table+"</table>");
                        }else{
                            return("");
                        }
                    }
            
                    function pa_pagedetails(data, searchvalue) {
                        var newdata = [];
                        for ( var i = 0; i < data["rows"].length; i = i + 1 ){
                            var sant=1;
                            for ( var j = 0; j < newdata.length; j = j + 1 ){
                                if (data["rows"][i][0]+data["rows"][i][1]+data["rows"][i][2]+data["rows"][i][3]==newdata[j][0]+newdata[j][1]+newdata[j][2]+newdata[j][3]){
                                    newdata[j][6] = parseInt(newdata[j][6]) + parseInt(data["rows"][i][6]);
                                    sant = 0;
                                }
                            }
                            if (sant){
                                newdata.push(data["rows"][i].slice());
                            }
                        }
            
                        var countrfr = 0;
                        var countkwd = 0;
                        var countdrt = 0;
                        var countscl = 0;
                        var tablerfr = "";
                        var tablekwd = "";
                        var tablescl = "";
                        var tabledrt = "";
                        for ( var i = 0; i < newdata.length; i = i + 1 ) {
                            if (newdata[i][0] == searchvalue){
                                var pagetitle = newdata[i][5];
                                switch (newdata[i][3]){
                                    case "REFERRAL":    countrfr += parseInt(newdata[ i ][6]);
                                                        tablerfr += "<tr><td class=\'pa-pgdetailsl\'>"+newdata[i][1]+"</td><td class=\'pa-pgdetailsr\'>"+newdata[ i ][6]+"</td></tr>";
                                                        break;
                                    case "ORGANIC":     countkwd += parseInt(newdata[ i ][6]);
                                                        tablekwd += "<tr><td class=\'pa-pgdetailsl\'>"+newdata[i][2]+"</td><td class=\'pa-pgdetailsr\'>"+newdata[ i ][6]+"</td></tr>";
                                                        break;
                                    case "SOCIAL":      countscl += parseInt(newdata[ i ][6]);
                                                        tablescl += "<tr><td class=\'pa-pgdetailsl\'>"+newdata[i][1]+"</td><td class=\'pa-pgdetailsr\'>"+newdata[ i ][6]+"</td></tr>";
                                                        break;
                                    case "DIRECT":      countdrt += parseInt(newdata[ i ][6]);
                                                        break;
                                };
                            };
                        };
                        if (countrfr){
                            tablerfr = "' . __ ( "REFERRALS", 'wp-analytify' ) . ' ("+countrfr+")"+tablerfr+"";
                        }
                        if (countkwd){
                            tablekwd = "' . __ ( "KEYWORDS", 'wp-analytify' ) . ' ("+countkwd+")"+tablekwd+"";
                        }
                        if (countscl){
                            tablescl = "' . __ ( "SOCIAL", 'wp-analytify' ) . ' ("+countscl+")"+tablescl+"";
                        }
                        if (countdrt){
                            tabledrt = "' . __ ( "DIRECT", 'wp-analytify' ) . ' ("+countdrt+")";
                        }
                        return (pagetitle);
                     }
                
                     function online_refresh(){
                        jQuery.post(ajaxurl, {action: "pa_get_online_data", pa_security: "'. wp_create_nonce('pa_get_online_data'). '"}, function(response){
                            var data = jQuery.parseJSON(response);
                            if (data["totalsForAllResults"]["ga:activeVisitors"]!==document.getElementById("pa-online").innerHTML){
                                jQuery("#pa-online").fadeOut("slow");
                                jQuery("#pa-online").fadeOut(500);
                                jQuery("#pa-online").fadeOut("slow", function() {
                                    if ((parseInt(data["totalsForAllResults"]["ga:activeVisitors"]))<(parseInt(document.getElementById("pa-online").innerHTML))){
                                    }else{
                                    }
                                    document.getElementById("pa-online").innerHTML = data["totalsForAllResults"]["ga:activeVisitors"];
                                });
                                jQuery("#pa-online").fadeIn("slow");
                                jQuery("#pa-online").fadeIn(500);
                                jQuery("#pa-online").fadeIn("slow", function() {
                                    
                                });
                            };
            
                            var pagepath = [];
                            var referrals = [];
                            var keywords = [];
                            var social = [];
                            var visittype = [];
                            if(data["rows"]){
                            for ( var i = 0; i < data["rows"].length; i = i + 1 ) {
                                pagepath.push( data["rows"][ i ][0] );
                                if (data["rows"][i][3]=="REFERRAL"){
                                    referrals.push( data["rows"][ i ][1] );
                                }
                                if (data["rows"][i][3]=="ORGANIC"){
                                    keywords.push( data["rows"][ i ][2] );
                                }
                                if (data["rows"][i][3]=="SOCIAL"){
                                    social.push( data["rows"][ i ][1] );
                                }
                                visittype.push( data["rows"][ i ][3] );
                            }
                        }
                            var upagepath = pagepath.filter(onlyUniqueValues);
                            var upagepathstats = [];
                            for ( var i = 0; i < upagepath.length; i = i + 1 ) {
                                upagepathstats[i]={"pagepath":upagepath[i],"count":countvisits(data,upagepath[i])};
                            }
                            upagepathstats.sort( function(a,b){ return b.count - a.count } );
            
                            var pgstatstable = "";
                            for ( var i = 0; i < upagepathstats.length; i = i + 1 ) {
                                if (i < 10 ){
                                    pgstatstable += "<tr class=\"pa-pline\"><td class=\"pa-pright\">"+(i+1)+"</td><td class=\"pa-pleft\"><a href=\"'.get_option("pt_webprofile_url").'"+upagepathstats[i].pagepath.substring(0,70)+"\" title=\""+pa_pagedetails(data, upagepathstats[i].pagepath)+"\" target=\"_blank\">"+pa_pagedetails(data, upagepathstats[i].pagepath)+"</a></td><td class=\"pa-pright\">"+upagepathstats[i].count+"</td></tr>";
                                }
                            }
                            document.getElementById("pa-pages").innerHTML="<br /><table class=\"pa-pg Real_Time_Statistics_table\"><tr><th class=\"wd_1\">#</th><th>Page Title</th><th class=\"wd_2\">Visitors</th></tr>"+pgstatstable+"</table>";
            
                            var ureferralsstats = [];
                            var ureferrals = referrals.filter(onlyUniqueValues);
                            for ( var i = 0; i < ureferrals.length; i = i + 1 ) {
                                ureferralsstats[i]={"value":ureferrals[i],"count":countvisits(data,ureferrals[i])};
                            }
                            ureferralsstats.sort( function(a,b){ return b.count - a.count } );
            
                            var ukeywordsstats = [];
                            var ukeywords = keywords.filter(onlyUniqueValues);
                            for ( var i = 0; i < ukeywords.length; i = i + 1 ) {
                                ukeywordsstats[i]={"value":ukeywords[i],"count":countvisits(data,ukeywords[i])};
                            }
                            ukeywordsstats.sort( function(a,b){ return b.count - a.count } );
            
                            var usocialstats = [];
                            var usocial = social.filter(onlyUniqueValues);
                            for ( var i = 0; i < usocial.length; i = i + 1 ) {
                                usocialstats[i]={"value":usocial[i],"count":countvisits(data,usocial[i])};
                            }
                            usocialstats.sort( function(a,b){ return b.count - a.count } );
            
                            var uvisittype = ["REFERRAL","ORGANIC","SOCIAL"];
                            document.getElementById("pa-tdo-right").innerHTML = "<div class=\"pa-bigtext\"><span class=\"count-visits\">" +countvisits(data,uvisittype[0])+ "</span><span class=\"source\"><a href=\"#\" title=\""+pa_generatetooltip(ureferralsstats)+"\">"+\'' . __ ( "REFERRAL", 'wp-analytify' ) . '\'+"</a></span></div>";
                            document.getElementById("pa-tdo-right").innerHTML += "<div class=\"pa-bigtext\"><span class=\"count-visits\">" +countvisits(data,uvisittype[1])+ "</span><span class=\"source\"><a href=\"#\" title=\""+pa_generatetooltip(ukeywordsstats)+"\">"+\'' . __ ( "ORGANIC", 'wp-analytify' ) . '\'+"</a></span></div>";
                            document.getElementById("pa-tdo-right").innerHTML += "<div class=\"pa-bigtext\"><span class=\"count-visits\">" +countvisits(data,uvisittype[2])+ "</span><span class=\"source\"><a href=\"#\" title=\""+pa_generatetooltip(usocialstats)+"\">"+\'' . __ ( "SOCIAL", 'wp-analytify' ) . '\'+"</a></span></div>";
            
                            var uvisitortype = ["DIRECT","NEW","RETURNING"];
                            document.getElementById("pa-tdo-rights").innerHTML = "<div class=\"pa-bigtext\"><span class=\"count-visits\">" +countvisits(data,uvisitortype[0])+ "</span><span class=\"source\"><a href=\"#\" title=\"DIRECT Visitors\">"+\'' . __ ( "DIRECT", 'wp-analytify' ) . '\'+"</a></span></div>";
                            document.getElementById("pa-tdo-rights").innerHTML += "<div class=\"pa-bigtext\"><span class=\"count-visits\">" +countvisits(data,uvisitortype[1])+ "</span><span class=\"source\"><a href=\"#\" title=\"NEW Visitors\">"+\'' . __ ( "NEW", 'wp-analytify' ) . '\'+"</a></span></div>";
                            document.getElementById("pa-tdo-rights").innerHTML += "<div class=\"pa-bigtext\"><span class=\"count-visits\">" +countvisits(data,uvisitortype[2])+ "</span><span class=\"source\"><a href=\"#\" title=\"RETURNING Visitors\">"+\'' . __ ( "RETURNING", 'wp-analytify' ) . '\'+"</a></span></div>";
            
                            if (!data["totalsForAllResults"]["ga:activeVisitors"]){
                                location.reload();
                            }
            
                        });
                   };
                   online_refresh();
                   setInterval(online_refresh, 20000);
                   </script>';
                
                return $code;
        }

        /* 
        * Grab RealTime Data 
        */

        public function pa_realtime_data() {

            $profile_id = get_option("pt_webprofile_dashboard");
            $metrics = 'ga:activeVisitors';
            $dimensions = 'ga:pagePath,ga:source,ga:keyword,ga:trafficType,ga:visitorType,ga:pageTitle';

            try {       
                
                $data = $this->service->data_realtime->get ( 'ga:' . $profile_id, $metrics, array (
                                'dimensions' => $dimensions
                        ) );
            }
                
            catch ( Exception $e ) {
                
                update_option ( 'pa_lasterror_occur', esc_html($e));
                return '';
            }

            return $data;           
        }


        public function pa_welcome_message() {

            $pointer_content = '<h3>Analytify - Google Analytics for WordPress.</h3>';
            $pointer_content .= '<p>Thank you for activating Analytify Plugin. Enjoy Google Analytics for everything in WordPress.</p>';

            ?>
            
            <script type="text/javascript">
                //<![CDATA[
                jQuery(document).ready( function($) {

                    $('#toplevel_page_pa-dashboard').pointer({
                            content: '<?php echo $pointer_content; ?>',
                            position: 'left',
                            close: function() {
                                <?php update_option("pa_welcome_message",1) ?>
                            }
                    }).pointer('open');
                });
                //]]>
            </script>

            <?php
        }

        function analytify_plugin_updater() {

            // retrieve our license key from the DB
            $wpa_license_key = trim( get_option( 'analytify_license_key' ) );

            // setup the updater
            $edd_updater = new EDD_SL_Plugin_Updater( ANALYTIFY_STORE_URL, __FILE__, array( 
                    'version'   => '1.2.2',               // current version number
                    'license'   => $wpa_license_key,        // license key (used get_option above to retrieve from DB)
                    'item_name' => ANALYTIFY_PRODUCT_NAME,    // name of this plugin
                    'author'    => 'Muhammad Adnan'  // author of this plugin
                )
            );

        }

        function wp_analytify_register_option() {
            // creates our settings in the options table
            register_setting('analytify-settings', 'analytify_license_key', array( $this, 'analytify_sanitize_license' ));
        }


        function analytify_sanitize_license( $new ) {

          $old = get_option( 'analytify_license_key' );
          
          if( $old && $old != $new ) {

            delete_option( 'analytify_license_status' ); // new license has been entered, so must reactivate
          
          }
          return $new;
        }

        /************************************
        * Activate a license key
        *************************************/

        function analytify_activate_license() {

          // listen for our activate button to be clicked
          if( isset( $_POST['analytify_license_activate'] ) ) {
            
            // run a quick security check 
            if( ! check_admin_referer( 'analytify_nonce', 'analytify_nonce' ) )   
              
              return; // get out if we didn't click the Activate button

            // retrieve the license from the database
            $license = trim( get_option( 'analytify_license_key' ) );
              

            // data to send in our API request
            $api_params = array( 
              'edd_action'=> 'activate_license',
              'license'   => $license, 
              'item_name' => urlencode( ANALYTIFY_PRODUCT_NAME ), // the name of our product in EDD
              'url'       => home_url()
            );
            
            // Call the custom API.
            $response = wp_remote_get( add_query_arg( $api_params, ANALYTIFY_STORE_URL ), array( 'timeout' => 15, 'sslverify' => false ) );

            // make sure the response came back okay
            if ( is_wp_error( $response ) )
              
              return false;

            // decode the license data
            $license_data = json_decode( wp_remote_retrieve_body( $response ) );
            //print_r($license_data);

            // $license_data->license will be either "valid" or "invalid"

            update_option( 'analytify_license_status', $license_data->license );

          }
        }

        /***********************************************
        * Illustrates how to deactivate a license key.
        * This will descrease the site count
        ***********************************************/

        function analytify_deactivate_license() {

          // listen for our activate button to be clicked
          if( isset( $_POST['analytify_license_deactivate'] ) ) {

            // run a quick security check 
            if( ! check_admin_referer( 'analytify_nonce', 'analytify_nonce' ) )   
              return; // get out if we didn't click the Activate button

            // retrieve the license from the database
            $license = trim( get_option( 'analytify_license_key' ) );
              

            // data to send in our API request
            $api_params = array( 
              'edd_action'=> 'deactivate_license', 
              'license'   => $license, 
              'item_name' => urlencode( ANALYTIFY_PRODUCT_NAME ), // the name of our product in EDD
              'url'       => home_url()
            );
            
            // Call the custom API.
            $response = wp_remote_get( add_query_arg( $api_params, ANALYTIFY_STORE_URL ), array( 'timeout' => 15, 'sslverify' => false ) );

            // make sure the response came back okay
            if ( is_wp_error( $response ) )
                return false;

            // decode the license data
            $license_data = json_decode( wp_remote_retrieve_body( $response ) );

            // $license_data->license will be either "deactivated" or "failed"
            if( $license_data->license == 'deactivated' ){
              
              delete_option( 'analytify_license_key' );
              unset($license);
              delete_option( 'analytify_license_status' );
            
            }
          }
        }

        function analytify_check_license() {

            global $wp_version;

            $license = trim( get_option( 'analytify_license_key' ) );

            $api_params = array( 
                'edd_action' => 'check_license', 
                'license' => $license, 
                'item_name' => urlencode( ANALYTIFY_PRODUCT_NAME ),
                'url'       => home_url()
            );

            // Call the custom API.
            $response = wp_remote_get( add_query_arg( $api_params, ANALYTIFY_STORE_URL ), array( 'timeout' => 15, 'sslverify' => false ) );

            if ( is_wp_error( $response ) )
                return false;

            $license_data = json_decode( wp_remote_retrieve_body( $response ) );

            if( $license_data->license == 'valid' ) {
                return 'valid';
                // this license is still valid
            }
            else {
                return 'invalid';
            // this license is no longer valid
            }
        }
    }
} // End if class_exists check



function wp_analytify_load() {
    
    WP_Analytify::instance();
}

add_action( 'plugins_loaded', 'wp_analytify_load' );


/**
 *
 * @since       1.2.2
 * @return      void
 */
function wp_analytify_activation() {
   
    update_option( 'analytify_posts_stats', array( 'post','page' ));
    update_option( 'post_analytics_disable_back'  ,   1 );
    if( FALSE === get_option('analytify_disable_front') ) update_option( 'analytify_disable_front'  ,   1 );
    update_option( 'post_analytics_settings_back' , array( 'show-overall-back' ) );
    update_option( 'post_analytics_access_back'   , array( 'editor','administrator' ) );
    update_option( 'display_tracking_code'        , array( 'administrator' ) );
    update_option( 'show_welcome_page'            ,  0 );
}

register_activation_hook( __FILE__, 'wp_analytify_activation' );

/**
 *
 * @since       1.2.2
 * @return      void
 */
function wp_analytify_de_activation() {

        delete_option( 'analytify_posts_stats' );
        delete_option( 'show_welcome_page' );
        delete_option( 'pa_google_token' );
        delete_option( 'pa_welcome_message' );
        delete_option( 'post_analytics_token' );
}

register_deactivation_hook( __FILE__, 'wp_analytify_de_activation' );
?>